==> apoplast-1.0.4.tar.gz: apoplast-1.0.4/structures/modules/apoplast/clouds/supp_NIH/nature/measured_ingredient/_status/status_1.py <==

'''
	python3 insurance.py clouds/supp_NIH/nature/measured_ingredient/_status/status_1.py
'''

import apoplast.clouds.supp_NIH.nature.measured_ingredient as measured_ingredient_builder

import json

def check_1 ():
	measured_ingredient = measured_ingredient_builder.build (
		form = {
            "unit": "gram",
            "amount per package": "454",
            "serving size amount": "12",
            "amount is an estimate": "yes"
        },
		NIH_ingredient = {
			"order": 19,
			"ingredientId": 281043,
			"description": "",
			"notes": "",
			"quantity": [
				{
					"servingSizeOrder": 1,
					"servingSizeQuantity": 12,
					"operator": "=",
					"quantity": 75.7,
					"unit": "mg",
					"dailyValueTargetGroup": [
						{
							"name": "Adults and children 4 or more years of age",
							"operator": "=",
							"percent": 6,
							"footnote": None
						}
					],
					"servingSizeUnit": "Gram(s)"
				}
			],
			"nestedRows": [],
			"name": "Calcium",
			"category": "mineral",
			"ingredientGroup": "Calcium",
			"uniiCode": "SY7Q814VUP",
			"alternateNames": [
				"Ca"
			],
			"forms": []
		}
	)

	#print (json.dumps (measured_ingredient, indent = 4))

	assert (
		measured_ingredient ==
		{
			"name": "Calcium",
			"alternate names": [
				"Ca"
			],
			'listed measure': {'amount': {'fraction string': '15980741802747495/17592186044416', 'decimal string': '908.400'}, 'unit kind': 'mass', 'unit': 'mg', 'operator': '='},
			"measures": {
				"mass + mass equivalents": {
					"per package": {
						"is equivalent": "no",
						'listed operator': '=',
						"listed": [
							"908.400",
							"mg"
						],
						"grams": {
							"decimal string": "0.908",
							"fraction string": "3196148360549499/3518437208883200"
						}
					}
				}
			},
			"unites": []
		}
	), measured_ingredient

	return;
	
	
checks = {
	'check 1': check_1
}

==> apoplast-1.0.7.tar.gz: apoplast-1.0.7/structures/modules/apoplast/clouds/supp_NIH/nature/measured_ingredient/_status/status_1.py <==

'''
	python3 insurance.py clouds/supp_NIH/nature/measured_ingredient/_status/status_1.py
'''

import apoplast.clouds.supp_NIH.nature.measured_ingredient as measured_ingredient_builder

import rich

def check_1 ():
	'''
		454
	'''
	measured_ingredient = measured_ingredient_builder.build (
		form = {
            "unit": "gram",
            "amount per package": "454",
            "serving size amount": "12",
            "amount is an estimate": "yes"
        },
		NIH_ingredient = {
			"order": 19,
			"ingredientId": 281043,
			"description": "",
			"notes": "",
			"quantity": [
				{
					"servingSizeOrder": 1,
					"servingSizeQuantity": 12,
					"operator": "=",
					"quantity": 75.7,
					"unit": "mg",
					"dailyValueTargetGroup": [
						{
							"name": "Adults and children 4 or more years of age",
							"operator": "=",
							"percent": 6,
							"footnote": None
						}
					],
					"servingSizeUnit": "Gram(s)"
				}
			],
			"nestedRows": [],
			"name": "Calcium",
			"category": "mineral",
			"ingredientGroup": "Calcium",
			"uniiCode": "SY7Q814VUP",
			"alternateNames": [
				"Ca"
			],
			"forms": []
		}
	)

	rich.print_json (data = measured_ingredient)
	
	'''
		2.8639833333333335 grams 
			= (.0757 / 12) * 454
	'''
	assert (
		measured_ingredient ["measures"] ["mass + mass equivalents"] ["per form"] ["grams"] ["fraction string"] ==
		"355127595616611/56294995342131200"
	)
	
	'''
		0.006 grams?
			(.0757 / 12) = 0.006308333333333334
	'''
	assert (
		measured_ingredient ["measures"] ["mass + mass equivalents"] ["per package"] ["grams"] ["fraction string"] ==
		"80613964204970697/28147497671065600"
	)



	return;
	
	
checks = {
	'check 1': check_1
}
